Started to work on topology abstraction.
Added more unit tests.
Changed mastership application to be synchronous.
diff --git a/net/api/src/main/java/org/onlab/onos/net/EdgeLink.java b/net/api/src/main/java/org/onlab/onos/net/EdgeLink.java
index 356592d3..b1d5f7f 100644
--- a/net/api/src/main/java/org/onlab/onos/net/EdgeLink.java
+++ b/net/api/src/main/java/org/onlab/onos/net/EdgeLink.java
@@ -17,8 +17,8 @@
      * Returns the connection point where the host attaches to the
      * network infrastructure.
      *
      * @return host connection point
      */
-    ConnectPoint connectPoint();
+    HostLocation hostLocation();
 
 }
@@ -17,8 +17,8 @@
      * network infrastructure.
      *
-     * @return host connection point
+     * @return host location point
      */